---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE]"
labels: ''
assignees: ''

---

**Is this related to a PeakRDL sub-command?**
If so, please open an issue in the appropriate `PeakRDL-***` project: https://github.com/orgs/SystemRDL/repositories

**Describe the problem/limitation you think should be addressed**
A clear and concise description of what the problem is.

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or about the feature request here.
